# Jump Conditions and Dynamic Surface Tension at Non-material Interfaces

LaTeX source codes for the text of my Bachelor Thesis.

---

## Tracked Files

| filename | description |
|----------|-------------|
|`abstract.tex` | standalone abstract to be uploaded to SIS |
|`abstract.xmpdata` | metadata for standalone abstract|
|`appendix_coupled_calculus.tex` | proofs of theorems and lemmata used in Colombeau algebra chapter|
|`appendix_modified_reynolds.tex` | proof of modified Reynolds transport theorem|
|`bibliography.bib` | BibTeX file containing references|
|`bibliography.tex` | inclusion of bibliography in the main document|
|`chap_01.tex` | **Formulation of Mechanical Problems on Domains with Singular Surfaces**|
|`chap_02.tex` | **Dynamic Surface Tension - Motivation**|
|`chap_03.tex` | **Dynamic Surface Tension - Analytical Insights** |
|`chap_04.tex` | **Generalized Solutions of the Governing Equations** |
|`chap_05.tex` | **Discussion and Open Problems** |
|`epilog.tex` | **Conclusion** |
|`macros.tex` | my commands and environments|
|`Makefile` .|for compilation using the `make` utility (*useless?*)|
|`nomenclature.tex` | entries for the List of Symbols and Abbreviations| 
|`pdfa.xmpi` | PDF/A format stuff|
|`preface.tex` | **Introduction** |
|`README.html` | HTML export of this document (*useless?*)|
|`README.md` | this document|
|`thesis.tex` | main document|
|`thesis.xmpdata` | metadata for main document|
|`title.tex` | title page |

## Document Structure & Compilation

The thesis is split into multiple LaTeX documents, `thesis.tex` being the main body. Some of the longer parts of the structure (e.g. chapters) are included in the main document via the `subfiles` package. These documents have the preamble
```latex
\documentclass[thesis.tex]{subfiles}
```
They can be compiled independently (recommended for editing just the one specific file) and are included in the main body as `\subfile{filename}`.

Smaller parts of the document structure are incorporated into the main document simply as `\include{filename}` and cannot be compiled by themselves.

## List of Symbols and Abbreviations

The List of Symbols and Abbreviations is generated via the `nomencl` package. The file `nomenclature.tex` contains entries in the format
```latex
\nomenclature[key]{symbol}{description}
```
The `key` field corresponds to a category of the symbol. The list of categories is below. The categories appear in alphabetical order of keys in the document.

| key | category name |
|-----|---------------|
| `A` | Number Sets |
| `B` | Vector Spaces |
| `C` | Vector Analysis Operators|
| `D` | Physical Quantities |
| `O` | Other symbols |
| `Z` | Abbreviations |

In order for the List of Symbols and Abbreviations to be compiled correctly, the compilation recipe to use is **pdflatex → bibtex → makeindex → pdflatex → pdflatex**.

## Global TO DO List

- [ ] Dedication
- [ ] Abstract
- [ ] Keywords
- [ ] Introduction
- [ ] Chapter 1: Formulation of Mechanical Problems on Domains with Singular Surfaces
- [ ] Chapter 2: Dynamic Surface Tension - Motivation
- [ ] Chapter 3: Dynamic Surface Tension - Analytical Insights
- [ ] Chapter 4: Generalized Solutions of Governing equations
- [ ] Chapter 5: Discussion and Open Problems
- [ ] Conclusion
- [ ] Bibliography
- [ ] List of Figures
- [ ] List of Abbreviations (?)
- [ ] Appendix: Attachments (?)
- [ ] Appendix: Coupled Calculus Properties
- [ ] standalone abstract: english
- [ ] standalone abstract: slovak

## Known Issues

Below is a more specific TO DO list consisting of smaller tasks or issues to be addressed.

<!-- - [ ] remember to write about ODEs and PDEs in the Introduction and introduce the abbreviations (or maybe it is enough to include both in the List of Abbreviations) -->
<!-- - [x] consider adding page numbers to citations of exact passages of reference materials -->
<!-- - [x] move derivation of modified Reynolds theorem to the end of the thesis as an appendix -->
- [ ] in proof of $`H^q \approx H`$ theorem ... do we use the property $`\chi' = \phi`$? if so, uncomment it
<!-- - [x] introduce/define the **jump** somewhere in Chapter 1 -->
<!-- - [x] review and possibly correct planar diffuse interface calculations  -->
<!-- - [x] create file for List of Symbols and Abbreviations -->
<!-- - [x] how to compare the general condition derived for modelling argument in CA to the Chambat jump condition? is it even necessary? -->
<!-- - [x] power law fluid definition & references -->
<!-- - [x] physical significance of the model $`\eta = \arctan{\delta}`$ -->
<!-- - [x] should I leave the `doi`s in the BibTeX entries? -->
- [ ] add slovak standalone abstract (with metadata)